#!/bin/sh
if [ -L $0 ] ; then
    BASEDIR=$(cd "$(dirname "$(readlink $0)")"; pwd -P) # for symbolic link
else
    BASEDIR=$(cd "$(dirname "$0")"; pwd -P) # for normal file
fi
PKG_DIR=${BASEDIR%/*}

source /etc/event_functions
NET_STATUS="/var/run/netstatus"


SEND_FILE="/var/run/test.txt"
UMOUNT="/bin/umount"

STUNNEL_DIR="/tmp/.vca"
SMTPS_CONF="/etc/conf.d/smtps.conf"
SSL_DIR="${PKG_DIR}/ssl"
PEM_FILE="${SSL_DIR}/private.pem"
CERT_FILE="${SSL_DIR}/public.cert"
HTTPS_CLIENT_CONF="${PKG_DIR}/conf.d/default/https_client.conf"
SSL_CONF="${PKG_DIR}/conf.d/usrdef/ssl.conf"

# program list
HTTP_CLIENT_PROG="/usr/sbin/httpclient"
STUNNEL_PROG="/usr/sbin/stunnel"
FTPMPUT_PROG="/usr/bin/ftpmput"
OPENSSL_PROG=$(which openssl)
SMTPC=$(which smtpclient)
CURL_PROG=$(which curl)
FTPS_PROG="/usr/sbin/ftps"
TINYXMLPARSER=$(which tinyxmlparser)

if [ -x "$(which sudo)" ];then
    SUDO="sudo -n "
fi
GENCERT="${SUDO} $(which gencert)"
CHOWN="${SUDO} $(which chown)"

KEYGEN_PROG="/usr/bin/ssh-keygen"
KEYSCAN_PROG="/usr/bin/ssh-keyscan"
MK_TEMP="/bin/mktemp"

[ -e ${CURL_PROG} ] && cURL="true"
getEncParam() {
    if [ "$REQUEST_METHOD" = "POST" ]; then
        strparam=$(cat $stdin | cut -c1-$CONTENT_LENGTH)
    else
        strparam=$QUERY_STRING
    fi

    echo "${strparam}"
}

decParam() {
    input=$1
    echo $(except_decode.sh ${input})
}

parseParam() {
    strparam=$1
    type=$(echo "$strparam" | sed -n 's/^.*type=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    address=$(echo "$strparam" | sed -n 's/^.*address=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    username=$(echo "$strparam" | sed -n 's/^.*username=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    passwd=$(echo "$strparam" | sed -n 's/^.*passwd=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    port=$(echo "$strparam" | sed -n 's/^.*port=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    sslmode=$(echo "$strparam" | sed -n 's/^.*sslmode=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    passive=$(echo "$strparam" | sed -n 's/^.*passive=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    location=$(echo "$strparam" | sed -n 's/^.*location=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    senderemail=$(echo "$strparam" | sed -n 's/^.*senderemail=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    recipientemail=$(echo "$strparam" | sed -n 's/^.*recipientemail=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    workgroup=$(echo "$strparam" | sed -n 's/^.*workgroup=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    url=$(echo "$strparam" | sed -n 's/^.*url=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    resType=$(echo "$strparam" | sed -n 's/^.*response=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    refTarget=$(echo "$strparam" | sed -n 's/^.*reftarget=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    refPasswdByIndex=$(echo "$strparam" | sed -n 's/^.*refpasswdbyindex=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")
    fingerprint=$(echo "$strparam" | sed -n 's/^.*fingerprint=\([^&]*\).*$/\1/p' | sed "s/%20/ /g")

    [ -z "$refTarget" ] && refTarget="reportpush"
}

preprocess_http_url() {
    if [ "$type" = "https" ]; then
        sslmode="true"
    else
        sslmode="false"
    fi

    target_url="${url#${type}://}"
    url="/${target_url#*/}"
    address_port="${target_url%%/*}"

    if [ "$(echo ${address_port} | sed -e 's/^\(.\{1\}\).*$/\1/')" == "[" ]; then
        if [ "$(echo ${address_port} | sed -e 's/\(^.*\)\(.$\)/\2/')" == "]" ]; then
            address="$(echo ${address_port} | sed 's/^.\(.*\).$/\1/')"
            port=80
        else
            targetUrl="$(echo ${address_port} | sed 's/\(.*\):/\1 /')"
            address="$(echo ${address_port} | cut -d ' ' -f 1 | sed 's/^.\(.*\).$/\1/')"
            port="$(echo ${address_port} | cut -d ' ' -f 2)"
        fi

        use_ipv6="v6"
    else
        address="${address_port%%:*}"
        if [ "${address}" != "${address_port}" ]; then
            port="${address_port#${address}:}"
        else
            port=80
        fi
    fi
}

parse_data_from_config() {
    ref_target=$1 && pass_index=$2 && ref_file=$3

    case "${ref_target}" in
    "validation")
        svrType="$(${TINYXMLPARSER} -x /Validation/i${pass_index}/ServerType -f ${ref_file})"

        case "${svrType}" in
            "ftp")
                svrAddr="$(${TINYXMLPARSER} -x /Validation/i${pass_index}/FTP/Address -f ${ref_file})"
                svrPort="$(${TINYXMLPARSER} -x /Validation/i${pass_index}/FTP/Port -f ${ref_file})"
                svrUser="$(${TINYXMLPARSER} -x /Validation/i${pass_index}/FTP/User -f ${ref_file})"
                svrPwd="$(${TINYXMLPARSER} -x /Validation/i${pass_index}/FTP/Password -f ${ref_file})"
                ;;
            "sftp")
                svrAddr="$(${TINYXMLPARSER} -x /Validation/i${pass_index}/SFTP/Address -f ${ref_file})"
                svrPort="$(${TINYXMLPARSER} -x /Validation/i${pass_index}/SFTP/Port -f ${ref_file})"
                svrUser="$(${TINYXMLPARSER} -x /Validation/i${pass_index}/SFTP/User -f ${ref_file})"
                svrPwd="$(${TINYXMLPARSER} -x /Validation/i${pass_index}/SFTP/Password -f ${ref_file})"
                ;;
        esac
        ;;
    "reportpush")
        svrType="$(${TINYXMLPARSER} -x /reportpush/i${pass_index}/servertypeselector -f ${ref_file})"
        svrAddr="$(${TINYXMLPARSER} -x /reportpush/i${pass_index}/url -f ${ref_file})"
        svrPort="$(${TINYXMLPARSER} -x /reportpush/i${pass_index}/port -f ${ref_file})"
        svrUser="$(${TINYXMLPARSER} -x /reportpush/i${pass_index}/usr -f ${ref_file})"
        svrPwd="$(${TINYXMLPARSER} -x /reportpush/i${pass_index}/pwd -f ${ref_file})"
        ;;
    esac
}

update_password() {
    pkgPath="$(dirname $(pwd))"

    if [ "${refTarget}" = "validation" ]; then
        config="${pkgPath}/conf.d/vca/config_${refTarget}.xml"
    else
        config="${pkgPath}/conf.d/vca/config_vca_${refTarget}.xml"
    fi

    parse_data_from_config ${refTarget} ${refPasswdByIndex} ${config}

    if [ "${svrType}" == "${type}" -a "${svrAddr}" == "${address}" -a "${svrPort}" == "${port}" -a "${svrUser}" == "${username}" ]; then
        passwd=${svrPwd}
    else
        resMsg="invalidPasswdRefer"
    fi

}

get_request_parameter() {
    strparam=$(getEncParam)
    strparam=$(decParam ${strparam})
    parseParam ${strparam}

    if [ "$type" = "http" -o "$type" = "https" ]; then
        preprocess_http_url
    fi

    if [ -n "${refPasswdByIndex}" -a -z "${passwd}" ]; then
        update_password
    fi
}

SUDO=""
if [ -x "$(which sudo)" ];then
    SUDO="$(which sudo) -n "
fi

checkNetStatus() {
    if [ ! -f "${NET_STATUS}" ]; then
        echo "false"
    else
        echo "true"
    fi
}

generate_ssl_key() {
    if [ -f "${PEM_FILE}" -a -f "${CERT_FILE}" ]; then
        "${OPENSSL_PROG}" x509 -noout -in "${CERT_FILE}" -checkend 86400
        [ "$?" == "0" ] && return
    fi

    [ ! -d "${SSL_DIR}" ] && mkdir -p "${SSL_DIR}"
    "${OPENSSL_PROG}" req -x509 -nodes -days 365 -newkey rsa:2048 -keyout "${PEM_FILE}" -out "${CERT_FILE}" -config "${SSL_CONF}" > /dev/null

    if [ ! -f "${PEM_FILE}" -o ! -f "${CERT_FILE}" ]; then
        echo "Generate SSL KEY failure"
    else
        chmod 600 "${PEM_FILE}" "${CERT_FILE}"
    fi
}

generate_test_file() {
    if [ ! -f "$SEND_FILE" ]; then
        echo "[NOTIFICATION]The Result of Server Test of Your IP Camera" >"$SEND_FILE"
    fi
}

gen_stunnel_config() {
    address="${1}"
    port="${2}"
    config="${3}"
    pid_file="${4}"
    protocol="${5}"
    local_port="${6}"

    if [ "${protocol}" == "smtps" ]; then
        [ -f "${SMTPS_CONF}" ] || return
        cp "${SMTPS_CONF}" "${config}"
    else
        [ -f "${HTTPS_CLIENT_CONF}" ] || return
        cp "${HTTPS_CLIENT_CONF}" "${config}"
    fi

    target_address="${address}:${port}"
    sed -i "s,connect[[:space:]]*=[[:space:]]*.*,connect = ${target_address},g" "${config}"
    sed -i "s,pid[[:space:]]*=[[:space:]]*.*,pid = $pid_file,g" "${config}"
    sed -i "s,cert[[:space:]]*=[[:space:]]*.*,cert = ${CERT_FILE},g" "${config}"
    sed -i "s,key[[:space:]]*=[[:space:]]*.*,key = ${PEM_FILE},g" "${config}"
    sed -i "s,accept[[:space:]]*=[[:space:]]*.*,accept = ${local_port},g" "${config}"
}

prepare_protocol_over_stunnel() {
    config="${1}"
    address="${2}"
    port="${3}"
    pid_file="${4}"
    protocol="${5}"
    local_port="${6}"

    [ "$(generate_ssl_key)" != "" ] && return

    gen_stunnel_config "${address}" "${port}" "${config}" "${pid_file}" "${protocol}" "${local_port}"

    "${STUNNEL_PROG}" "${config}"

    time_out=10
    while [ "${time_out}" -gt 0 ]
    do
        if [ "$(netstat -lnt | grep "LISTEN" | grep ":${local_port}")" != "" ]; then
            break
        fi
        sleep 1
        time_out="$(expr ${time_out} - 1)"
    done
}

getValidPort() {
    port_start=7000
    port_end=7050

    for port in $(seq "${port_start}" "${port_end}")
    do
        if [ "$(netstat -lnt | grep "LISTEN" | grep ":${port}")" == "" ]; then
            echo "${port}"
            return
        fi
    done
}

emailSvr() {
    exitStatus=0

    if [ -n "$address" ] && [ -n "$recipientemail" ]; then
        title="[NOTIFICATION]The Result of Server Test of Your IP Camera"
        mime_type="-M 2"

        if [ -n "$username" ]; then
            auth="-U ${username} -p ${passwd}"
        else
            auth=""
        fi

        if [ "$sslmode" = "1" ]; then
            tmpDir="${STUNNEL_DIR}/smtps/$$"
            mkdir -p "${tmpDir}"
            smtpsConfig="${tmpDir}/stunnel.conf"
            smtpsPid="${tmpDir}/stunnel.pid"
            localPort="$(getValidPort)"
            if [ "${localPort}" == "" ]; then
                resMsg="getLocallPortFail"
                exitStatus=1
                return
            fi
            prepare_protocol_over_stunnel "${smtpsConfig}" "${address}" "${port}" "${smtpsPid}" "smtps" "${localPort}"
            $SMTPC -s "$title" $mime_type -b $SEND_FILE -f "$senderemail" -S "127.0.0.1" -P "${localPort}" $auth "$recipientemail" $COS_PRIORITY_OPT $DSCP_PRIORITY_OPT
        else
            $SMTPC -s "$title" $mime_type -b $SEND_FILE -f "$senderemail" -S "$address" -P $port $auth "$recipientemail" $COS_PRIORITY_OPT $DSCP_PRIORITY_OPT
        fi

        if [ "$?" = "0" ]; then
            resMsg="sendEmailSuccess"
        else
            resMsg="sendEmailFail"
            exitStatus=1
        fi

        if [ "$sslmode" = "1" ]; then
            kill -9 $(cat "${smtpsPid}")
            rm -rf "${tmpDir}"
        fi
    else
        resMsg="errEmailAddr"
        exitStatus=1
    fi
}

ftpSvr() {
    exitStatus=0

    if [ -n "$address" ]; then
        if [ -n "$username" ]; then
            auth="-u $username -p $passwd"
        else
            auth=""
        fi

        if [ ! -n "$port" ]; then
            port="21"
        fi

        if [ "$passive" = "1" ]; then
            mode=""
        else
            . $NET_STATUS
            mode="-a $IP_ADDR"
        fi

        if [ -z $location ]; then
            DIR="."
        else
            DIR="$location"
        fi

        if [ -x ${FTPS_PROG} ]; then
            ${FTPS_PROG} $mode -t 60 $auth -P $port $address "$DIR" $SEND_FILE $COS_PRIORITY_OPT $DSCP_PRIORITY_OPT >/dev/null
        else
            ${FTPMPUT_PROG} $mode -t 60 $auth -P $port $address "$DIR" $SEND_FILE $COS_PRIORITY_OPT $DSCP_PRIORITY_OPT >/dev/null
        fi

        if [ "$?" = "0" ]; then
            resMsg="sendFtpSuccess"
        else
            resMsg="sendFtpFail"
            exitStatus=1
        fi
    else
        resMsg="errFtpAddr"
        exitStatus=1
    fi
}

updateKnownHost() {
    host_key="${1}"
    addr="${2}"
    port="${3}"
    md5="${4}"

    if [ "${port}" -eq 22 ]; then
        host_name="${addr}"
    else
        host_name="[${addr}]:${port}"
    fi

    if [ -f "${host_key}" ]; then
        if [ "$(${KEYGEN_PROG} -q -F ${host_name} -f ${host_key} -l -E md5 | grep "MD5:${md5}")" != "" ]; then
            return
        fi
    fi
    rm -f "${host_key}"

    temp_list="$(${MK_TEMP})"
    "${KEYSCAN_PROG}" -p "${port}" "${addr}" > "${temp_list}" 2> /dev/null
    if [ "$?" -ne 0 ]; then
        rm -f "${temp_list}"
        return
    fi

    num="$(wc "${temp_list}" -l | cut -d " " -f 1)"
    if [ "$?" -ne 0 -o "${num}" -ne "${num}" ]; then
        rm -f "${temp_list}"
        return
    fi

    temp_host_key="$(${MK_TEMP})"
    for i in $(seq 1 "${num}")
    do
        sed "${i}!d" "${temp_list}" > "${temp_host_key}"
        if [ "$?" -ne 0 ] ; then
            rm -f "${temp_list}" "${temp_host_key}"
            return
        fi

        if [ "$(${KEYGEN_PROG} -q -F ${host_name} -f ${temp_host_key} -l -E md5 | grep "MD5:${md5}")" != "" ]; then
            mv "${temp_host_key}" "${host_key}"
            rm -f "${temp_list}"
            return
        fi
    done

    rm -f "${temp_list}" "${temp_host_key}"
}

sftpSvr() {
    exitStatus=0
    workDir="${STUNNEL_DIR}/sftp/test"
    mkdir -p ${workDir}
    host_key="${workDir}/key"

    if [ -n "${address}" -a -n "${port}" -a -n "${username}" -a -n "${passwd}" ]; then
        if [ "${fingerprint}" != "" ]; then
            updateKnownHost "${host_key}" "${address}" "${port}" "${fingerprint}"
            ssh_option="-oUserKnownHostsFile=${host_key}"

            if [ ! -f "${host_key}" ]; then
                resMsg="errHostKey"
                exitStatus=1
            fi
        else
            ssh_option="-oStrictHostKeyChecking=no"
        fi

        if [ "${exitStatus}" -eq 0 ]; then
            sshpass_option="-e"
            ssh_option="$ssh_option -oNumberOfPasswordPrompts=1"
            sshpass_run="sudo -n SSHPASS=${passwd} /usr/bin/sshpass $sshpass_option"

            script_file="${workDir}/script"
            echo "put ${SEND_FILE}" > "${script_file}"
            echo "exit" >> "${script_file}"

            /bin/cat "${script_file}" | ${sshpass_run} /usr/bin/sftp -S /usr/bin/ssh ${ssh_option} -P ${port} ${username}@${address}:${location} > /dev/null
            if [ "$?" -eq 0 ]; then
                resMsg="sendSftpSuccess"
            else
                resMsg="sendSftpFail"
                exitStatus=1
            fi
            rm -f "${script_file}"
        fi
    else
        resMsg="errSftpInfo"
        exitStatus=1
    fi
}

httpSvr() {
    exitStatus=0

    if [ -n "$address" ]; then

        if [ "${sslmode}" = "true" ] && [ "${cURL}" != "true" ]; then
            tmpDir="${STUNNEL_DIR}/https/$$"
            mkdir -p "${tmpDir}"
            httpsConfig="${tmpDir}/stunnel.conf"
            httpsPid="${tmpDir}/stunnel.pid"
            localPort="$(getValidPort)"
            if [ "${localPort}" == "" ]; then
                resMsg="getLocallPortFail"
                exitStatus=1
                return
            fi
            prepare_protocol_over_stunnel "${httpsConfig}" "${address}" "${port}" "${httpsPid}" "https" "${localPort}"
            address=127.0.0.1
            port="${localPort}"
            use_ipv6=""
        fi

        if [ "${cURL}" = "true" ]; then
            [ "${use_ipv6}" = "v6" ] && address="[${address}]"
            http_ret_code=$("${CURL_PROG}" -s -o "/dev/null" -w "%{http_code}" "${type}://${address}:${port}${url}" -u "${username}:${passwd}" -F "data=@${SEND_FILE}" -k --connect-timeout 25)
        else
            $HTTP_CLIENT_PROG -M UPLOAD -t Text -file ${SEND_FILE} -S ${address} ${port} "${username}" "${passwd}" ${use_ipv6} -U "${url}" >/dev/null
        fi

        if [ "$?" = "0" -a "${cURL}" = "" -o "${cURL}" = "true" -a "${http_ret_code}" = "200" ]; then
            resMsg="sendHttpSuccess"
        else
            resMsg="sendHttpFail"
            exitStatus=1
        fi

        if [ "${sslmode}" = "true" ] && [ "${cURL}" != "true" ]; then
            kill -9 $(cat "${httpsPid}")
            rm -rf "${tmpDir}"
        fi
    else
        resMsg="errHttpAddr"
        exitStatus=1
    fi
}

nasSvr() {
    exitStatus=0
    smb_path="$(echo $location | sed -e 's#[\]#/#g')"
    tmp_path=${smb_path#//}
    smb_host=${tmp_path%%/*}
    tmp_path=${smb_path#//*/}
    smb_sharefolder=${tmp_path%%/*}
    smb_childfolder=${smb_path#//$smb_host/$smb_sharefolder}
    smb_path1="//${smb_host}/${smb_sharefolder}"

    destination_path="/mnt/auto/i99"
    if [ -n "$username" ]; then
        if [ -n "$workgroup" ]; then
            parameter="sec=ntlm,username=$username,password=$passwd,workgroup=$workgroup"
        else
            parameter="sec=ntlm,username=$username,password=$passwd"
        fi
    else
        parameter="sec=none"
    fi
    echo "i99 -fstype=cifs,$parameter :$smb_path1" >>/mnt/flash/etc/auto.conf
    cd $destination_path

    if [ "$?" = "0" ]; then
        cp $SEND_FILE $destination_path
        if [ "$?" = "0" ]; then
            resMsg="mountNasSuccess"
        else
            resMsg="nasDenied"
            exitStatus=1
        fi

        sleep 1
        cd /mnt/ramdisk
        $UMOUNT $destination_path
    else
        resMsg="mountNasFail"
        exitStatus=1
    fi

    sed -i '/i99 -fstype=cifs/d' /mnt/flash/etc/auto.conf
}

sdCard() {
    if [ -z "`ls /mnt/auto | grep CF`" ];then
        exitStatus=1
        resMsg="storeSdCardFail"
        return
    fi
    destination_folder="/mnt/auto/CF/vca_test"

    if [ ! -d "$destination_folder" ]; then
        ${SUDO} /bin/mkdir -p $destination_folder
        if [ -n "$SUDO" ];then
            ${SUDO} /bin/chown $(whoami) $destination_folder
        fi
    fi

    if [ ! -d "$destination_folder" ]; then
        resMsg="storeSdCardFail"
        exitStatus=1
        return
    fi

    cp $SEND_FILE $destination_folder

    if [ "$?" = "0" ]; then
        resMsg="storeSdCardSuccess"
        exitStatus=0
        rm $SEND_FILE
    else
        resMsg="storeSdCardFail"
        exitStatus=1
    fi
}

send_request_to_server() {
    if [ -z "$resMsg" ]; then
        if [ "$(checkNetStatus)" == "true" ]; then
            generate_test_file
            case "$type" in
            "email")
                emailSvr
                ;;
            "ftp")
                ftpSvr
                ;;
            "sftp")
                sftpSvr
                ;;
            "http" | "https")
                httpSvr
                ;;
            "ns")
                nasSvr
                ;;
            "sdcard")
                sdCard
                ;;
            esac
        else
            resMsg="checkNetFail"
        fi
    fi
    echo "$resMsg"
}
resHtmlHead()
{
    echo -ne "Content-type: text/html\r\n"
    echo -ne "\r\n"
    echo -ne "<html>\n
              <head>\n
              <meta http-equiv='Content-Type' content='text/html; charset=utf-8' />\n
              <script type='text/javascript' src='/include/common.js'></script>\n
              </head>\n
              <body>\n"
}

resHtmlTail()
{
    echo "</body></html>"
}

transHtml()
{
    echo -e "<script type="text/javascript">document.write(translator('$1'))</script>"
}

resHtml()
{
    respnse_msg=$1
    resHtmlHead
    case "${respnse_msg}" in
        "checkNetFail")
	        transHtml "please_check_internet_connection"
            ;;
        "sendEmailFail")
            transHtml "error_in_sending_email"
            ;;
        "sendEmailSuccess")
            transHtml "the_email_has_been_sent_successfully"
            connect_success=1
            ;;
        "errEmailAddr")
            transHtml "please_define_mail_server_location"
            ;;
        "sendFtpSuccess")
            transHtml "ftp_transmission_successfully"
            connect_success=1
            ;;
        "sendFtpFail")
            transHtml "ftp_transmission_failed"
            ;;
        "errFtpAddr")
            transHtml "please_define_ftp_address"
            ;;
        "sendHttpSuccess")
            transHtml "http_transmission_successfully"
            connect_success=1
            ;;
        "sendHttpFail")
            transHtml "http_transmission_failed"
            ;;
        "errHttpAddr")
            transHtml "please_define_a_valid_http_address"
            ;;
        "mountNasSuccess")
			transHtml "mount_successfully"
            connect_success=1
            ;;
        "nasDenied")
			transHtml "mount_success_but_transmit_denied"
            ;;
        "mountNasFail")
		    transHtml "mount_failed"
            ;;
        "storeSdCardSuccess")
			transHtml "test_sd_card_successfully"
            connect_success=1
            ;;
        "storeSdCardFail")
            transHtml "test_sd_failed"
	        transHtml "the_device_is_not_existed"
	        transHtml "check_sd_card"
            ;;
        "invalidPasswdRefer")
            echo "invalid password reference"
            ;;
        "getLocallPortFail")
            echo "can not get valid local port"
            ;;
        "errSftpInfo")
            echo "can not get sftp address, port, user account and password"
            ;;
        "errHostKey")
            echo "can not get host key"
            ;;
        "sendSftpSuccess")
            echo "send to sftp success"
            connect_success=1
            ;;
        "sendSftpFail")
            echo "send to sftp fail"
            ;;
        *)
            ;;
    esac

    resHtmlTail
}

resJson()
{
    echo -ne "Content-type: application/json\r\n"
    echo -ne "\r\n"

    respnse_msg=$1
    case "${respnse_msg}" in
        "sendEmailSuccess" | "sendFtpSuccess" | "sendHttpSuccess" | "mountNasSuccess" | "storeSdCardSuccess" | "sendSftpSuccess")
            echo "{\"testConnection\":\"success\"}"
            connect_success=1
            ;;
        "invalidPasswdRefer")
            echo "{\"testConnection\":\"invalid password reference\"}"
            ;;
        "getLocallPortFail")
            echo "{\"testConnection\":\"can not get valid local port\"}"
            ;;
        "errSftpInfo")
            echo "{\"testConnection\":\"can not get sftp address, port, user account and password\"}"
            ;;
        "errHostKey")
            echo "{\"testConnection\":\"can not get host key\"}"
            ;;
        "sendSftpFail")
            echo "{\"testConnection\":\"send to sftp fail\"}"
            ;;
        *)
            echo "{\"testConnection\":\"fail\"}"
            ;;
    esac
}

response_from_server()
{
    response_msg="$1"
    if [ "${resType}" == "json" ]; then
        resJson $response_msg
    else
        resHtml $response_msg
    fi
}



get_qos_eventalarm_settings
get_request_parameter

connect_success=0
response_msg=$(send_request_to_server)
response_from_server ${response_msg}

exit ${connect_success}


